using System;
using System.Collections.Generic;
using System.Text;

namespace Monitoring
{
    /// <summary>
    /// A class that must be implemented by any of the listeners that 
    /// listen for a heartbeat from this application
    /// </summary>
    /// <remarks >
    /// There are two possible constructors - either with no parameters or, if initialisation data is to be
    /// passed in the InitData="" property a constructor with a single string must be provided.
    /// </remarks>
    public abstract class HeartbeatMonitorBase : MarshalByRefObject, IDisposable
    {

        private string _name = @"";

        /// <summary>
        /// The name of the heartbeat monitor
        /// </summary>
        /// <remarks >
        /// This value must be unique in any heartbeatMonitors collection
        /// </remarks>
        public virtual string Name 
        { 
            get 
           { 
            return _name; 
           } 
           set
           { 
               _name = value; 
           }
        }

        /// <summary>
        /// A heartbeat has been triggered and should be acted on
        /// </summary>
        public   abstract void Beat() ;

        /// <summary>
        /// A heartbeat has been tiggered with extra Beatvalue information
        /// </summary>
        /// <param name="BeatValue">
        /// An integer which can provide extra information for the heartbeat
        /// </param>
        /// <remarks >
        /// The meaning of the BeatValue parameter is entirely up to the listener to interpret
        /// </remarks>
        public abstract void Beat(int BeatValue);


        public void Dispose() { }
        public void Dispose(bool Disposing) { }

    }
}
